/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#ifndef __BOARD_HEADER__
#define __BOARD_HEADER__

#include <qwidget.h>
#include <qtimer.h>
#include "SpriteCollection.h"
#include <time.h>

class Board : public QWidget
{
    Q_OBJECT

public:
    Board(QWidget *parent, const char *name = 0, WFlags f = 0);
    ~Board();

public:
    static const int rows = 10;
    static const int cols = 10;
    static const int tilesize = 24;
    static const int queuesize = 4;
    static const int smalltilesize = 16;

private:
    SpriteCollection *m_sprites;
    QTimer *m_timer;
    int m_time;
    int m_parts;
    int m_level;
    int m_parts_left;
    int m_time_left;
    int m_tile[rows][cols];
    int m_queue[queuesize];
    int m_placed;
    int m_destroyed;
    int m_connected;
    int m_not_connected;
    int m_filled;
    bool m_spilled;
    bool m_bonus_enabled;
    bool m_running;

public slots:
    void updateTime(int time);
    void updateParts(int parts);
    void updateLevel(int level);
    void start(void);
    void timeout(void);

protected:
    void showEvent(QShowEvent *event);
    void hideEvent(QHideEvent *event);
    void paintEvent(QPaintEvent *event);
    void mousePressEvent(QMouseEvent *event);

private:
    int getTimeForGame(void);
    int getPartsForGame(void);
    int getScoreForGame(void);
    void fillQueue(void);
    void pushQueue(void);
    int popQueue(void);
    int atQueuePos(int pos);
    void gameOver(void);
    void checkConnected(bool flag[rows][cols]);
    void checkPartConnected(bool flag[rows][cols], int row, int col);
    void checkSpilled(bool flag[rows][cols]);
    bool checkSpilledOneRound(bool flag[rows][cols]);
    bool hasLeft(int which);
    bool hasRight(int which);
    bool hasUp(int which);
    bool hasDown(int which);
};

#endif // __BOARD_HEADER__

