/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#include <qwidget.h>
#include <qpixmap.h>
#include <qbitmap.h>
#include <qimage.h>
#include <qpainter.h>
#include "SpriteCollection.h"
#include "images/data.c"

SpriteCollection::SpriteCollection(QWidget *parent)
{
    m_parent = parent;
    m_background.loadFromData(tile_data_, sizeof (tile_data_));
    m_tile[0].loadFromData(tile_l_data_, sizeof (tile_l_data_));
    m_tile[1].loadFromData(tile_r_data_, sizeof (tile_r_data_));
    m_tile[2].loadFromData(tile_u_data_, sizeof (tile_u_data_));
    m_tile[3].loadFromData(tile_d_data_, sizeof (tile_d_data_));
    m_tile[4].loadFromData(tile_lr_data_, sizeof (tile_lr_data_));
    m_tile[5].loadFromData(tile_ud_data_, sizeof (tile_ud_data_));
    m_tile[6].loadFromData(tile_lu_data_, sizeof (tile_lu_data_));
    m_tile[7].loadFromData(tile_ld_data_, sizeof (tile_ld_data_));
    m_tile[8].loadFromData(tile_ru_data_, sizeof (tile_ru_data_));
    m_tile[9].loadFromData(tile_rd_data_, sizeof (tile_rd_data_));
    m_tile[10].loadFromData(tile_lud_data_, sizeof (tile_lud_data_));
    m_tile[11].loadFromData(tile_rud_data_, sizeof (tile_rud_data_));
    m_tile[12].loadFromData(tile_lru_data_, sizeof (tile_lru_data_));
    m_tile[13].loadFromData(tile_lrd_data_, sizeof (tile_lrd_data_));
    m_tile[14].loadFromData(tile_lrud_data_, sizeof (tile_lrud_data_));
    m_tile[15].loadFromData(tile_start_data_, sizeof (tile_start_data_));
    m_tile[16].loadFromData(full_tile_l_data_, sizeof (full_tile_l_data_));
    m_tile[17].loadFromData(full_tile_r_data_, sizeof (full_tile_r_data_));
    m_tile[18].loadFromData(full_tile_u_data_, sizeof (full_tile_u_data_));
    m_tile[19].loadFromData(full_tile_d_data_, sizeof (full_tile_d_data_));
    m_tile[20].loadFromData(full_tile_lr_data_, sizeof (full_tile_lr_data_));
    m_tile[21].loadFromData(full_tile_ud_data_, sizeof (full_tile_ud_data_));
    m_tile[22].loadFromData(full_tile_lu_data_, sizeof (full_tile_lu_data_));
    m_tile[23].loadFromData(full_tile_ld_data_, sizeof (full_tile_ld_data_));
    m_tile[24].loadFromData(full_tile_ru_data_, sizeof (full_tile_ru_data_));
    m_tile[25].loadFromData(full_tile_rd_data_, sizeof (full_tile_rd_data_));
    m_tile[26].loadFromData(full_tile_lud_data_, sizeof (full_tile_lud_data_));
    m_tile[27].loadFromData(full_tile_rud_data_, sizeof (full_tile_rud_data_));
    m_tile[28].loadFromData(full_tile_lru_data_, sizeof (full_tile_lru_data_));
    m_tile[29].loadFromData(full_tile_lrd_data_, sizeof (full_tile_lrd_data_));
    m_tile[30].loadFromData(full_tile_lrud_data_, sizeof (full_tile_lrud_data_));
    m_tile[31].loadFromData(full_tile_start_data_, sizeof (full_tile_start_data_));
    m_small_tile[0].loadFromData(small_tile_l_data_, sizeof (small_tile_l_data_));
    m_small_tile[1].loadFromData(small_tile_r_data_, sizeof (small_tile_r_data_));
    m_small_tile[2].loadFromData(small_tile_u_data_, sizeof (small_tile_u_data_));
    m_small_tile[3].loadFromData(small_tile_d_data_, sizeof (small_tile_d_data_));
    m_small_tile[4].loadFromData(small_tile_lr_data_, sizeof (small_tile_lr_data_));
    m_small_tile[5].loadFromData(small_tile_ud_data_, sizeof (small_tile_ud_data_));
    m_small_tile[6].loadFromData(small_tile_lu_data_, sizeof (small_tile_lu_data_));
    m_small_tile[7].loadFromData(small_tile_ld_data_, sizeof (small_tile_ld_data_));
    m_small_tile[8].loadFromData(small_tile_ru_data_, sizeof (small_tile_ru_data_));
    m_small_tile[9].loadFromData(small_tile_rd_data_, sizeof (small_tile_rd_data_));
    m_small_tile[10].loadFromData(small_tile_lud_data_, sizeof (small_tile_lud_data_));
    m_small_tile[11].loadFromData(small_tile_rud_data_, sizeof (small_tile_rud_data_));
    m_small_tile[12].loadFromData(small_tile_lru_data_, sizeof (small_tile_lru_data_));
    m_small_tile[13].loadFromData(small_tile_lrd_data_, sizeof (small_tile_lrd_data_));
    m_small_tile[14].loadFromData(small_tile_lrud_data_, sizeof (small_tile_lrud_data_));
    m_small_tile[15].loadFromData(small_tile_start_data_, sizeof (small_tile_start_data_));
}

void SpriteCollection::drawTile(QPainter &painter, int x, int y, int which)
{
    painter.drawPixmap(x, y, m_background);
    if (which >= 0 && which < 32) {
	painter.drawPixmap(x, y, m_tile[which]);
    }
}

void SpriteCollection::drawSmallTile(QPainter &painter, int x, int y, int which)
{
    if (which >= 0 && which < 16) {
	painter.drawPixmap(x, y, m_small_tile[which]);
    }
}

